<?php

namespace Drupal\quick_edit_variation\Controller;

use Drupal\commerce_product\Entity\ProductInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\DependencyInjection\ClassResolverInterface;
use Drupal\Core\Form\FormState;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines quick edit variation controller.
 */
class QuickEditVariationController extends ControllerBase {

  /**
   * The class resolver.
   *
   * @var \Drupal\Core\DependencyInjection\ClassResolverInterface
   */
  protected ClassResolverInterface $classResolver;

  /**
   * Constructs a new QuickEditVariationController object.
   *
   * @param \Drupal\Core\DependencyInjection\ClassResolverInterface $class_resolver
   *   The class resolver.
   */
  public function __construct(ClassResolverInterface $class_resolver) {
    $this->classResolver = $class_resolver;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('class_resolver')
    );
  }

  /**
   * Provide quick edit page.
   *
   * @param \Drupal\commerce_product\Entity\ProductInterface $commerce_product
   *   The commerce product.
   *
   * @return array
   *   The build values.
   *
   * @throws \Drupal\Core\Form\EnforcedResponseException
   * @throws \Drupal\Core\Form\FormAjaxException
   */
  public function quickEdit(ProductInterface $commerce_product) {
    /** @var \Drupal\commerce_product\Entity\ProductVariationInterface $variations */
    $variations = $commerce_product->get('variations')->referencedEntities();
    $build = [];
    foreach ($variations as $variation) {
      $form_object = $this->classResolver->getInstanceFromDefinition('\Drupal\quick_edit_variation\Form\QuickEditVariationForm');
      $form_object->setVariation($variation);
      $form_state = new FormState();
      $form = $this->formBuilder()->buildForm($form_object, $form_state);
      $build['form'][] = $form;
      $build['#title'] = t('Edit @product_title', ['@product_title' => $commerce_product->getTitle()]);
      $build['#attached']['library'][] = 'quick_edit_variation/quick_edit_variation_dialog';
    }
    return $build;
  }

}
